@@ -607,7 +607,6 @@ module.exports = {
 	"9.3.3": "83.0.4103.122",
 	"9.3.4": "83.0.4103.122",
 	"9.3.5": "83.0.4103.122",
-	"9.4.0": "83.0.4103.122",
 	"10.0.0-beta.1": "84.0.4129.0",
 	"10.0.0-beta.2": "84.0.4129.0",
 	"10.0.0-beta.3": "85.0.4161.2",
@@ -697,7 +696,6 @@ module.exports = {
 	"10.1.5": "85.0.4183.121",
 	"10.1.6": "85.0.4183.121",
 	"10.1.7": "85.0.4183.121",
-	"10.2.0": "85.0.4183.121",
 	"11.0.0-beta.1": "86.0.4234.0",
 	"11.0.0-beta.3": "86.0.4234.0",
 	"11.0.0-beta.4": "86.0.4234.0",
@@ -760,20 +758,12 @@ module.exports = {
 	"11.0.2": "87.0.4280.67",
 	"11.0.3": "87.0.4280.67",
 	"11.0.4": "87.0.4280.67",
-	"11.0.5": "87.0.4280.88",
-	"11.1.0": "87.0.4280.88",
-	"11.1.1": "87.0.4280.88",
 	"12.0.0-beta.1": "89.0.4328.0",
 	"12.0.0-beta.3": "89.0.4328.0",
 	"12.0.0-beta.4": "89.0.4328.0",
 	"12.0.0-beta.5": "89.0.4328.0",
 	"12.0.0-beta.6": "89.0.4328.0",
 	"12.0.0-beta.7": "89.0.4328.0",
-	"12.0.0-beta.8": "89.0.4328.0",
-	"12.0.0-beta.9": "89.0.4328.0",
-	"12.0.0-beta.10": "89.0.4328.0",
-	"12.0.0-beta.11": "89.0.4328.0",
-	"12.0.0-beta.12": "89.0.4328.0",
 	"12.0.0-nightly.20200827": "86.0.4234.0",
 	"12.0.0-nightly.20200831": "86.0.4234.0",
 	"12.0.0-nightly.20200902": "86.0.4234.0",
@@ -808,13 +798,5 @@ module.exports = {
 	"13.0.0-nightly.20201204": "89.0.4328.0",
 	"13.0.0-nightly.20201207": "89.0.4328.0",
 	"13.0.0-nightly.20201208": "89.0.4328.0",
-	"13.0.0-nightly.20201209": "89.0.4328.0",
-	"13.0.0-nightly.20201210": "89.0.4328.0",
-	"13.0.0-nightly.20201211": "89.0.4328.0",
-	"13.0.0-nightly.20201214": "89.0.4328.0",
-	"13.0.0-nightly.20201215": "89.0.4349.0",
-	"13.0.0-nightly.20201216": "89.0.4349.0",
-	"13.0.0-nightly.20201221": "89.0.4349.0",
-	"13.0.0-nightly.20201222": "89.0.4349.0",
-	"13.0.0-nightly.20201223": "89.0.4359.0"
+	"13.0.0-nightly.20201209": "89.0.4328.0"
 };
\ No newline at end of file
